
/*
 * Data related to a file.
 *
 * Only the fields required by this application are specified here.
 */


Ext.define('POSync.model.File', {
    extend:     'Ext.data.TreeModel',
    idProperty: 'id',
    fields: [
        'id',			// The system wide unique ID for this object (-> cr_items.item_id)
                                // FIXME: could better be file_id
        'name',			// The name and extension (without path) of the file or folder
        'version_id',		// The active version of the file (-> cr_revisions.revision_id) (empty string for folders)
        'description',		// Description of the file or folder
	'title',		// Title of the file or folder
        'iconCls',              // Used by ExtJS for the icon, seems to work
                                // FIXME: should be generated automatically from 'type' (icon-TYPE)
	'content_length',	// File length in bytes (empty string for folders)
	'sha1',			// sha-1 Hash of the content (empty string for folders)
        'expanded',             // true or false (without quotes), default state for tree
	'type',			// 'folder' for folders and the mime-type for file
	'leaf',			// false for folders, true for files
        // added by SALO
        'level',                // FIXME: let ExtJS calculate this
        'mime_type',            // FIXME: same as 'type' for files, and empty string for folders
        'publish_date',         // empty string for folders
        'children'              // undefined for files, a (possibly empty) array for folders
    ],

    /**
     * Returns the path of the file, starting with root.
     */
    getPathArray: function() {
        var me = this;

        // Skip the root and the 1st level folder, which refers to the project itself.
        if ("root" == me.get('id')) return [];
        if ("root" == me.get('parentId')) return [];

        var fileType = me.get('type');
        var parentId = me.get('parentId');
        if (!parentId) return [me.get('name')];
        var fileStore = Ext.StoreManager.get('Files');
        var parent = fileStore.getById(parentId);
        if (!parent) return [me.get('name')];
        var parentPath = parent.getPathArray();

		// For a file return just the path (=parentPath)
        if ("folder" != fileType) return parentPath;

		// For a folder, add the folder name to the path
        parentPath.push(me.get('name'));
        return parentPath;
    }

});